@@ -24,12 +24,6 @@
 #' not (FALSE).
 #' @param add whether to add the layer to an existing plot (TRUE) or 
 #' not (FALSE).
-#' @param spdf defunct.
-#' @param spdfid defunct.
-#' @param spdfids defunct.
-#' @param spdfide defunct.
-#' @param dfids defunct.
-#' @param dfide defunct.
 #' @note Unlike most of cartography functions, identifiers fields are mandatory.
 #' @seealso \link{getLinkLayer}, \link{propLinkLayer}, \link{legendGradLines}
 #' @examples
@@ -59,17 +53,8 @@ gradLinkLayer <- function(x, df, xid = NULL, dfid = NULL,
                           legend.values.cex = 0.6, 
                           legend.values.rnd = 0,
                           legend.frame = FALSE, 
-                          add = TRUE, 
-                          spdf, spdfid, spdfids, spdfide, dfids, dfide){
-  
-  
-  if(sum(c(missing(spdf), missing(spdfid), missing(spdfids), missing(spdfide), 
-           missing(dfids), missing(dfide))) != 6){
-    stop("spdf, spdfid, spdfids, spdfide, dfids and dfide are defunct arguments; last used in version 1.4.2.",
-         call. = FALSE)
-  }
-  
-  
+                          add = TRUE){
+
   # test
   if((length(breaks)-1) != length(lwd)){
     stop("length(lwd) must be equal to length(breaks) - 1",call. = FALSE)
